package br.exemplodragdrop;


import android.app.Activity;
import android.content.ClipData;
import android.content.ClipDescription;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.DragEvent;
import android.view.View;
import android.view.View.DragShadowBuilder;
import android.view.View.OnDragListener;
import android.view.View.OnLongClickListener;
import android.view.ViewGroup;
import android.widget.LinearLayout;

public class MainActivity extends Activity {
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		findViewById(R.id.img1).setOnLongClickListener(new MyOnLongClickListener());
		findViewById(R.id.img2).setOnLongClickListener(new MyOnLongClickListener());
		findViewById(R.id.img3).setOnLongClickListener(new MyOnLongClickListener());
		findViewById(R.id.img4).setOnLongClickListener(new MyOnLongClickListener());
		
		findViewById(R.id.topleft).setOnDragListener(new MyOnDragListener(1));
		findViewById(R.id.topright).setOnDragListener(new MyOnDragListener(2));
		findViewById(R.id.bottomleft).setOnDragListener(new MyOnDragListener(3));
		findViewById(R.id.bottomright).setOnDragListener(new MyOnDragListener(4));
	}
	
	
	class MyOnLongClickListener implements OnLongClickListener {
		@Override
		public boolean onLongClick(View v) {
			ClipData data = ClipData.newPlainText("simple_text", "text");
			DragShadowBuilder sb = new View.DragShadowBuilder(findViewById(R.id.shadow));
			v.startDrag(data, sb, v, 0);
			v.setVisibility(View.INVISIBLE);
			return(true);
		}
	}
	
	class MyOnDragListener implements OnDragListener {
		private int num;
		
		public MyOnDragListener(int num){
			super();
			this.num = num;
		}
		
		@Override
		public boolean onDrag(View v, DragEvent event) {
			int action = event.getAction();
			
			switch(action){
				case DragEvent.ACTION_DRAG_STARTED:
					Log.i("Script", num+" - ACTION_DRAG_STARTED");
					if(event.getClipDescription().hasMimeType(ClipDescription.MIMETYPE_TEXT_PLAIN)){
						return(true);
					}
					return(false);
				case DragEvent.ACTION_DRAG_ENTERED:
					Log.i("Script", num+" - ACTION_DRAG_ENTERED");
					v.setBackgroundColor(Color.YELLOW);
					break;
				case DragEvent.ACTION_DRAG_LOCATION:
					Log.i("Script", num+" - ACTION_DRAG_LOCATION");
					break;
				case DragEvent.ACTION_DRAG_EXITED:
					Log.i("Script", num+" - ACTION_DRAG_EXITED");
					v.setBackgroundColor(Color.BLUE);
					break;
				case DragEvent.ACTION_DROP:
					Log.i("Script", num+" - ACTION_DROP");
					View view = (View) event.getLocalState();
					ViewGroup owner = (ViewGroup) view.getParent();
					owner.removeView(view);
					LinearLayout container = (LinearLayout) v;
					container.addView(view);
					view.setVisibility(View.VISIBLE);
					break;
				case DragEvent.ACTION_DRAG_ENDED:
					Log.i("Script", num+" - ACTION_DRAG_ENDED");
					v.setBackgroundColor(Color.BLUE);
					break;
			}
			
			return true;
		}
	}
	
}
